# coding: utf-8

# flake8: noqa
"""
    Vayu Events Api

    The Vayu Event Ingestion API is a RESTful API that allows you to submit events for processing and storage. The API is secured using the Bearer Authentication scheme with JWT tokens. To obtain a JWT token, please contact Vayu at team@withvayu.com 

    The version of the OpenAPI document: 2.3.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


# import models into model package
from openapi_client.models.event_input import EventInput
from openapi_client.models.login_request import LoginRequest
from openapi_client.models.login_response import LoginResponse
from openapi_client.models.send_events_request import SendEventsRequest
